==> hdtool-center-api-1.1.0-20180416.090022-1-sources.jar: cn/com/duiba/hdtool/center/api/params/HdtoolParam.java <==
package cn.com.duiba.hdtool.center.api.params;

import java.util.List;

/**
 * ClassName:HdtoolParam<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 活动工具查询参数
 * @date 创建时间：2018/3/9  19:30
 * @since JDK 1.8
 **/
public class HdtoolParam  extends PageParams {

    private static final long serialVersionUID = -8015460410083316845L;
    //标题
    private String  title;
    //id
    private Long id;
    //subType
    private String  subType;
    //factoryKey
    private String  factoryKey;
    //extend
    private String  extend;
    //extend
    private List<Long> ids;
    //删除状态
    private Boolean deleted;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getFactoryKey() {
        return factoryKey;
    }

    public void setFactoryKey(String factoryKey) {
        this.factoryKey = factoryKey;
    }

    public String getExtend() {
        return extend;
    }

    public void setExtend(String extend) {
        this.extend = extend;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }
}

==> hdtool-center-api-1.1.34-20220115.060213-2-sources.jar: cn/com/duiba/hdtool/center/api/params/HdtoolParam.java <==
package cn.com.duiba.hdtool.center.api.params;

import java.util.List;

/**
 * ClassName:HdtoolParam<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 活动工具查询参数
 * @date 创建时间：2018/3/9  19:30
 * @since JDK 1.8
 **/
public class HdtoolParam  extends PageParams {

    private static final long serialVersionUID = -8015460410083316845L;
    //标题
    private String  title;
    //id
    private Long id;
    //subType
    private String  subType;
    //factoryKey
    private String  factoryKey;
    //extend
    private String  extend;
    //extend
    private List<Long> ids;
    //删除状态
    private Boolean deleted;
    //开启状态
    private Integer status;

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getFactoryKey() {
        return factoryKey;
    }

    public void setFactoryKey(String factoryKey) {
        this.factoryKey = factoryKey;
    }

    public String getExtend() {
        return extend;
    }

    public void setExtend(String extend) {
        this.extend = extend;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }
}
